# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OperationResult(UniversalBaseModel):
    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Message describing the result. If the virtual card link was sent successfully, this contains the email address to which the link was sent.
    """

    success: bool = pydantic.Field()
    """
    Indicates whether the operation was successful.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class TierItem(UniversalBaseModel):
    amountx_auth: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="amountxAuth")] = None
    high_pay_range: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="highPayRange")] = None
    low_pay_range: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="lowPayRange")] = None
    percentx_auth: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="percentxAuth")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.additional_data_string import AdditionalDataString
from ...types.billing_address_addtl_nullable import BillingAddressAddtlNullable
from ...types.billing_address_nullable import BillingAddressNullable
from ...types.billing_city_nullable import BillingCityNullable
from ...types.billing_country_nullable import BillingCountryNullable
from ...types.billing_state_nullable import BillingStateNullable
from ...types.billing_zip import BillingZip
from ...types.customer_id import CustomerId
from ...types.customer_number_nullable import CustomerNumberNullable
from ...types.customer_status import CustomerStatus
from ...types.email import Email
from ...types.identifierfields import Identifierfields
from ...types.phone_number import PhoneNumber
from ...types.shippingaddress import Shippingaddress
from ...types.shippingaddressadditional import Shippingaddressadditional
from ...types.shippingcity import Shippingcity
from ...types.shippingcountry import Shippingcountry
from ...types.shippingstate import Shippingstate
from ...types.shippingzip import Shippingzip


class TransactionDetailCustomer(UniversalBaseModel):
    """
    Customer information associated with the transaction
    """

    identifiers: typing.Optional[Identifierfields] = None
    first_name: typing_extensions.Annotated[str, FieldMetadata(alias="firstName")]
    last_name: typing_extensions.Annotated[str, FieldMetadata(alias="lastName")]
    company_name: typing_extensions.Annotated[str, FieldMetadata(alias="companyName")]
    billing_address_1: typing_extensions.Annotated[BillingAddressNullable, FieldMetadata(alias="billingAddress1")]
    billing_address_2: typing_extensions.Annotated[BillingAddressAddtlNullable, FieldMetadata(alias="billingAddress2")]
    billing_city: typing_extensions.Annotated[BillingCityNullable, FieldMetadata(alias="billingCity")]
    billing_state: typing_extensions.Annotated[BillingStateNullable, FieldMetadata(alias="billingState")]
    billing_zip: typing_extensions.Annotated[BillingZip, FieldMetadata(alias="billingZip")]
    billing_country: typing_extensions.Annotated[BillingCountryNullable, FieldMetadata(alias="billingCountry")]
    billing_phone: typing_extensions.Annotated[PhoneNumber, FieldMetadata(alias="billingPhone")]
    billing_email: typing_extensions.Annotated[Email, FieldMetadata(alias="billingEmail")]
    customer_number: typing_extensions.Annotated[CustomerNumberNullable, FieldMetadata(alias="customerNumber")]
    shipping_address_1: typing_extensions.Annotated[Shippingaddress, FieldMetadata(alias="shippingAddress1")]
    shipping_address_2: typing_extensions.Annotated[Shippingaddressadditional, FieldMetadata(alias="shippingAddress2")]
    shipping_city: typing_extensions.Annotated[Shippingcity, FieldMetadata(alias="shippingCity")]
    shipping_state: typing_extensions.Annotated[Shippingstate, FieldMetadata(alias="shippingState")]
    shipping_zip: typing_extensions.Annotated[Shippingzip, FieldMetadata(alias="shippingZip")]
    shipping_country: typing_extensions.Annotated[Shippingcountry, FieldMetadata(alias="shippingCountry")]
    customer_id: typing_extensions.Annotated[CustomerId, FieldMetadata(alias="customerId")]
    customer_status: typing_extensions.Annotated[CustomerStatus, FieldMetadata(alias="customerStatus")]
    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalDataString], FieldMetadata(alias="additionalData")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...types.authcode import Authcode
from ...types.avsresponsetext import Avsresponsetext
from ...types.cvvresponsetext import Cvvresponsetext
from ...types.order_id import OrderId
from ...types.resulttext import Resulttext


class TransactionDetailResponseData(UniversalBaseModel):
    """
    Response data from payment processor
    """

    response: typing.Optional[str] = None
    responsetext: Resulttext
    authcode: typing.Optional[Authcode] = None
    transactionid: str
    avsresponse: typing.Optional[str] = None
    avsresponse_text: typing.Optional[Avsresponsetext] = None
    cvvresponse: typing.Optional[str] = None
    cvvresponse_text: typing.Optional[Cvvresponsetext] = None
    orderid: typing.Optional[OrderId] = None
    type: typing.Optional[str] = None
    response_code: str
    response_code_text: str
    customer_vault_id: typing.Optional[str] = None
    emv_auth_response_data: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .is_success import IsSuccess
from .page_identifier import PageIdentifier
from .payabli_api_response_0_response_data import PayabliApiResponse0ResponseData
from .response_text import ResponseText


class PayabliApiResponse0(UniversalBaseModel):
    """
    General response for certain `moneyIn` and `moneyOut` endpoints.
    """

    is_success: typing_extensions.Annotated[typing.Optional[IsSuccess], FieldMetadata(alias="isSuccess")] = None
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier")
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[PayabliApiResponse0ResponseData], FieldMetadata(alias="responseData")
    ] = None
    response_text: typing_extensions.Annotated[ResponseText, FieldMetadata(alias="responseText")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.file_content_ftype import FileContentFtype
from .raw_client import AsyncRawOcrClient, RawOcrClient
from .types.payabli_api_response_ocr import PayabliApiResponseOcr
from .types.type_result import TypeResult

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class OcrClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawOcrClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawOcrClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawOcrClient
        """
        return self._raw_client

    def ocr_document_form(
        self,
        type_result: TypeResult,
        *,
        ftype: typing.Optional[FileContentFtype] = OMIT,
        filename: typing.Optional[str] = OMIT,
        furl: typing.Optional[str] = OMIT,
        f_content: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponseOcr:
        """
        Use this endpoint to upload an image file for OCR processing. The accepted file formats include PDF, JPG, JPEG, PNG, and GIF. Specify the desired type of result (either 'bill' or 'invoice') in the path parameter `typeResult`. The response will contain the OCR processing results, including extracted data such as bill number, vendor information, bill items, and more.

        Parameters
        ----------
        type_result : TypeResult

        ftype : typing.Optional[FileContentFtype]

        filename : typing.Optional[str]
            The name of the file to be uploaded

        furl : typing.Optional[str]
            Optional URL link to the file

        f_content : typing.Optional[str]
            Base64-encoded file content

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponseOcr
            OCR document processing result

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.ocr.ocr_document_form(
            type_result="typeResult",
        )
        """
        _response = self._raw_client.ocr_document_form(
            type_result, ftype=ftype, filename=filename, furl=furl, f_content=f_content, request_options=request_options
        )
        return _response.data

    def ocr_document_json(
        self,
        type_result: TypeResult,
        *,
        ftype: typing.Optional[FileContentFtype] = OMIT,
        filename: typing.Optional[str] = OMIT,
        furl: typing.Optional[str] = OMIT,
        f_content: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponseOcr:
        """
        Use this endpoint to submit a Base64-encoded image file for OCR processing. The accepted file formats include PDF, JPG, JPEG, PNG, and GIF. Specify the desired type of result (either 'bill' or 'invoice') in the path parameter `typeResult`. The response will contain the OCR processing results, including extracted data such as bill number, vendor information, bill items, and more.

        Parameters
        ----------
        type_result : TypeResult

        ftype : typing.Optional[FileContentFtype]

        filename : typing.Optional[str]
            The name of the file to be uploaded

        furl : typing.Optional[str]
            Optional URL link to the file

        f_content : typing.Optional[str]
            Base64-encoded file content

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponseOcr
            OCR document processing result

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.ocr.ocr_document_json(
            type_result="typeResult",
        )
        """
        _response = self._raw_client.ocr_document_json(
            type_result, ftype=ftype, filename=filename, furl=furl, f_content=f_content, request_options=request_options
        )
        return _response.data


class AsyncOcrClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawOcrClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawOcrClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawOcrClient
        """
        return self._raw_client

    async def ocr_document_form(
        self,
        type_result: TypeResult,
        *,
        ftype: typing.Optional[FileContentFtype] = OMIT,
        filename: typing.Optional[str] = OMIT,
        furl: typing.Optional[str] = OMIT,
        f_content: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponseOcr:
        """
        Use this endpoint to upload an image file for OCR processing. The accepted file formats include PDF, JPG, JPEG, PNG, and GIF. Specify the desired type of result (either 'bill' or 'invoice') in the path parameter `typeResult`. The response will contain the OCR processing results, including extracted data such as bill number, vendor information, bill items, and more.

        Parameters
        ----------
        type_result : TypeResult

        ftype : typing.Optional[FileContentFtype]

        filename : typing.Optional[str]
            The name of the file to be uploaded

        furl : typing.Optional[str]
            Optional URL link to the file

        f_content : typing.Optional[str]
            Base64-encoded file content

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponseOcr
            OCR document processing result

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.ocr.ocr_document_form(
                type_result="typeResult",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.ocr_document_form(
            type_result, ftype=ftype, filename=filename, furl=furl, f_content=f_content, request_options=request_options
        )
        return _response.data

    async def ocr_document_json(
        self,
        type_result: TypeResult,
        *,
        ftype: typing.Optional[FileContentFtype] = OMIT,
        filename: typing.Optional[str] = OMIT,
        furl: typing.Optional[str] = OMIT,
        f_content: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponseOcr:
        """
        Use this endpoint to submit a Base64-encoded image file for OCR processing. The accepted file formats include PDF, JPG, JPEG, PNG, and GIF. Specify the desired type of result (either 'bill' or 'invoice') in the path parameter `typeResult`. The response will contain the OCR processing results, including extracted data such as bill number, vendor information, bill items, and more.

        Parameters
        ----------
        type_result : TypeResult

        ftype : typing.Optional[FileContentFtype]

        filename : typing.Optional[str]
            The name of the file to be uploaded

        furl : typing.Optional[str]
            Optional URL link to the file

        f_content : typing.Optional[str]
            Base64-encoded file content

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponseOcr
            OCR document processing result

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.ocr.ocr_document_json(
                type_result="typeResult",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.ocr_document_json(
            type_result, ftype=ftype, filename=filename, furl=furl, f_content=f_content, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class StatBasicExtendedQueryRecord(UniversalBaseModel):
    stat_x: typing_extensions.Annotated[str, FieldMetadata(alias="statX")] = pydantic.Field()
    """
    The time window based on the mode and frequency used for the query.
    """

    out_customers: typing_extensions.Annotated[int, FieldMetadata(alias="outCustomers")] = pydantic.Field()
    """
    Number of active vendors.
    """

    out_new_customers: typing_extensions.Annotated[int, FieldMetadata(alias="outNewCustomers")] = pydantic.Field()
    """
    Number of new vendors.
    """

    out_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="outTransactions")] = pydantic.Field()
    """
    Outbound (payout) transactions count.
    """

    out_subscriptions_paid: typing_extensions.Annotated[int, FieldMetadata(alias="outSubscriptionsPaid")] = (
        pydantic.Field()
    )
    """
    Recurring outbound (payout) transactions count.
    """

    out_card_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="outCardTransactions")] = (
        pydantic.Field()
    )
    """
    Outbound (payout) pCard transactions count.
    """

    out_v_card_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="outVCardTransactions")] = (
        pydantic.Field()
    )
    """
    Outbound (payout) vCard transactions count.
    """

    out_ach_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="outACHTransactions")] = pydantic.Field()
    """
    Outbound (payout) ACH transactions count.
    """

    out_check_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="outCheckTransactions")] = (
        pydantic.Field()
    )
    """
    Outbound (payout) check transactions count.
    """

    out_pending_method_transactions: typing_extensions.Annotated[
        int, FieldMetadata(alias="outPendingMethodTransactions")
    ] = pydantic.Field()
    """
    Outbound (payout) Managed Payables transactions count.
    """

    out_transactions_volume: typing_extensions.Annotated[float, FieldMetadata(alias="outTransactionsVolume")] = (
        pydantic.Field()
    )
    """
    Outbound (payout) volume.
    """

    out_subscriptions_paid_volume: typing_extensions.Annotated[
        float, FieldMetadata(alias="outSubscriptionsPaidVolume")
    ] = pydantic.Field()
    """
    Recurring outbound (payout) volume.
    """

    out_card_volume: typing_extensions.Annotated[float, FieldMetadata(alias="outCardVolume")] = pydantic.Field()
    """
    Outbound (payout) pCard transactions volume.
    """

    out_v_card_volume: typing_extensions.Annotated[float, FieldMetadata(alias="outVCardVolume")] = pydantic.Field()
    """
    Outbound (payout) vCard transactions volume.
    """

    out_ach_volume: typing_extensions.Annotated[float, FieldMetadata(alias="outACHVolume")] = pydantic.Field()
    """
    Outbound (payout) ACH transactions volume.
    """

    out_check_volume: typing_extensions.Annotated[float, FieldMetadata(alias="outCheckVolume")] = pydantic.Field()
    """
    Outbound (payout) check transactions volume.
    """

    out_pending_method_volume: typing_extensions.Annotated[float, FieldMetadata(alias="outPendingMethodVolume")] = (
        pydantic.Field()
    )
    """
    Outbound (payout) Managed Payables volume.
    """

    in_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inTransactions")] = pydantic.Field()
    """
    Inbound transactions count.
    """

    in_subscriptions_paid: typing_extensions.Annotated[int, FieldMetadata(alias="inSubscriptionsPaid")] = (
        pydantic.Field()
    )
    """
    Inbound recurring transactions count.
    """

    in_customers: typing_extensions.Annotated[int, FieldMetadata(alias="inCustomers")] = pydantic.Field()
    """
    Number of active customers.
    """

    in_new_customers: typing_extensions.Annotated[int, FieldMetadata(alias="inNewCustomers")] = pydantic.Field()
    """
    Number of new customers.
    """

    in_card_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inCardTransactions")] = pydantic.Field()
    """
    Inbound card transactions count.
    """

    in_ach_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inACHTransactions")] = pydantic.Field()
    """
    Inbound ACH transactions count.
    """

    in_check_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inCheckTransactions")] = (
        pydantic.Field()
    )
    """
    Inbound check transactions count.
    """

    in_cash_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inCashTransactions")] = pydantic.Field()
    """
    Inbound cash transactions count.
    """

    in_wallet_transactions: typing_extensions.Annotated[int, FieldMetadata(alias="inWalletTransactions")] = (
        pydantic.Field()
    )
    """
    Inbound wallet transactions count.
    """

    in_card_charge_backs: typing_extensions.Annotated[int, FieldMetadata(alias="inCardChargeBacks")] = pydantic.Field()
    """
    Inbound card chargebacks and returns count.
    """

    in_ach_returns: typing_extensions.Annotated[int, FieldMetadata(alias="inACHReturns")] = pydantic.Field()
    """
    Inbound ACH returns count.
    """

    in_transactions_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inTransactionsVolume")] = (
        pydantic.Field()
    )
    """
    Inbound volume.
    """

    in_subscriptions_paid_volume: typing_extensions.Annotated[
        float, FieldMetadata(alias="inSubscriptionsPaidVolume")
    ] = pydantic.Field()
    """
    Inbound recurring payments volume.
    """

    in_card_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inCardVolume")] = pydantic.Field()
    """
    Inbound card volume.
    """

    in_ach_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inACHVolume")] = pydantic.Field()
    """
    Inbound ACH volume.
    """

    in_check_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inCheckVolume")] = pydantic.Field()
    """
    Inbound check volume.
    """

    in_cash_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inCashVolume")] = pydantic.Field()
    """
    Inbound cash volume recognized.
    """

    in_wallet_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inWalletVolume")] = pydantic.Field()
    """
    Inbound wallet transactions.
    """

    in_card_charge_back_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inCardChargeBackVolume")] = (
        pydantic.Field()
    )
    """
    Inbound Card chargebacks and returns volume.
    """

    in_ach_returns_volume: typing_extensions.Annotated[float, FieldMetadata(alias="inACHReturnsVolume")] = (
        pydantic.Field()
    )
    """
    Inbound ACH returns volume.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.ach_holder_type import AchHolderType
from ...types.ach_sec_code import AchSecCode
from ...types.batch_number import BatchNumber
from ...types.chargeback_id import ChargebackId
from ...types.dbaname import Dbaname
from ...types.device import Device
from ...types.entrypage_id import EntrypageId
from ...types.entrypointfield import Entrypointfield
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.external_processor_information import ExternalProcessorInformation
from ...types.fee_amount import FeeAmount
from ...types.ip_address import IpAddress
from ...types.legalname import Legalname
from ...types.operation import Operation
from ...types.order_id import OrderId
from ...types.org_parent_name import OrgParentName
from ...types.orgid import Orgid
from ...types.payor_id import PayorId
from ...types.paypoint_id import PaypointId
from ...types.pending_fee_amount import PendingFeeAmount
from ...types.query_c_fee_transaction import QueryCFeeTransaction
from ...types.refund_id import RefundId
from ...types.retrieval_id import RetrievalId
from ...types.returned_id import ReturnedId
from ...types.risk_action import RiskAction
from ...types.risk_action_code import RiskActionCode
from ...types.risk_flagged import RiskFlagged
from ...types.risk_flagged_on import RiskFlaggedOn
from ...types.risk_reason import RiskReason
from ...types.risk_status import RiskStatus
from ...types.settlement_status import SettlementStatus
from ...types.source import Source
from ...types.split_funding import SplitFunding
from ...types.trans_status import TransStatus
from .transaction_detail_customer import TransactionDetailCustomer
from .transaction_detail_event import TransactionDetailEvent
from .transaction_detail_invoice_data import TransactionDetailInvoiceData
from .transaction_detail_payment_data import TransactionDetailPaymentData
from .transaction_detail_record_method import TransactionDetailRecordMethod
from .transaction_detail_response_data import TransactionDetailResponseData


class TransactionDetailRecord(UniversalBaseModel):
    """
    Complete transaction details including payment information, customer data, and processing metadata. This is returned when includeDetails=true.
    """

    parent_org_name: typing_extensions.Annotated[OrgParentName, FieldMetadata(alias="parentOrgName")]
    paypoint_dbaname: typing_extensions.Annotated[Dbaname, FieldMetadata(alias="paypointDbaname")]
    paypoint_legalname: typing_extensions.Annotated[Legalname, FieldMetadata(alias="paypointLegalname")]
    paypoint_entryname: typing_extensions.Annotated[Entrypointfield, FieldMetadata(alias="paypointEntryname")]
    payment_trans_id: typing_extensions.Annotated[str, FieldMetadata(alias="paymentTransId")]
    connector_name: typing_extensions.Annotated[str, FieldMetadata(alias="connectorName")]
    external_processor_information: typing_extensions.Annotated[
        ExternalProcessorInformation, FieldMetadata(alias="externalProcessorInformation")
    ]
    gateway_trans_id: typing_extensions.Annotated[str, FieldMetadata(alias="gatewayTransId")]
    order_id: typing_extensions.Annotated[typing.Optional[OrderId], FieldMetadata(alias="orderId")] = None
    method: TransactionDetailRecordMethod
    batch_number: typing_extensions.Annotated[BatchNumber, FieldMetadata(alias="batchNumber")]
    batch_amount: typing_extensions.Annotated[float, FieldMetadata(alias="batchAmount")]
    payor_id: typing_extensions.Annotated[PayorId, FieldMetadata(alias="payorId")]
    payment_data: typing_extensions.Annotated[TransactionDetailPaymentData, FieldMetadata(alias="paymentData")]
    trans_status: typing_extensions.Annotated[TransStatus, FieldMetadata(alias="transStatus")]
    paypoint_id: typing_extensions.Annotated[PaypointId, FieldMetadata(alias="paypointId")]
    total_amount: typing_extensions.Annotated[float, FieldMetadata(alias="totalAmount")]
    net_amount: typing_extensions.Annotated[float, FieldMetadata(alias="netAmount")]
    fee_amount: typing_extensions.Annotated[FeeAmount, FieldMetadata(alias="feeAmount")]
    settlement_status: typing_extensions.Annotated[SettlementStatus, FieldMetadata(alias="settlementStatus")]
    operation: Operation
    response_data: typing_extensions.Annotated[TransactionDetailResponseData, FieldMetadata(alias="responseData")]
    source: Source
    schedule_reference: typing_extensions.Annotated[int, FieldMetadata(alias="scheduleReference")]
    org_id: typing_extensions.Annotated[Orgid, FieldMetadata(alias="orgId")]
    refund_id: typing_extensions.Annotated[RefundId, FieldMetadata(alias="refundId")]
    returned_id: typing_extensions.Annotated[ReturnedId, FieldMetadata(alias="returnedId")]
    chargeback_id: typing_extensions.Annotated[ChargebackId, FieldMetadata(alias="chargebackId")]
    retrieval_id: typing_extensions.Annotated[RetrievalId, FieldMetadata(alias="retrievalId")]
    trans_additional_data: typing_extensions.Annotated[
        typing.Optional[typing.Any], FieldMetadata(alias="transAdditionalData")
    ] = None
    invoice_data: typing_extensions.Annotated[TransactionDetailInvoiceData, FieldMetadata(alias="invoiceData")]
    entrypage_id: typing_extensions.Annotated[EntrypageId, FieldMetadata(alias="entrypageId")]
    external_paypoint_id: typing_extensions.Annotated[ExternalPaypointId, FieldMetadata(alias="externalPaypointID")]
    is_validated_ach: typing_extensions.Annotated[bool, FieldMetadata(alias="isValidatedACH")]
    transaction_time: typing_extensions.Annotated[str, FieldMetadata(alias="transactionTime")]
    customer: TransactionDetailCustomer
    split_funding_instructions: typing_extensions.Annotated[
        typing.Optional[SplitFunding], FieldMetadata(alias="splitFundingInstructions")
    ] = None
    cfee_transactions: typing_extensions.Annotated[
        typing.List[QueryCFeeTransaction], FieldMetadata(alias="cfeeTransactions")
    ]
    transaction_events: typing_extensions.Annotated[
        typing.List[TransactionDetailEvent], FieldMetadata(alias="transactionEvents")
    ]
    pending_fee_amount: typing_extensions.Annotated[PendingFeeAmount, FieldMetadata(alias="pendingFeeAmount")]
    risk_flagged: typing_extensions.Annotated[RiskFlagged, FieldMetadata(alias="riskFlagged")]
    risk_flagged_on: typing_extensions.Annotated[RiskFlaggedOn, FieldMetadata(alias="riskFlaggedOn")]
    risk_status: typing_extensions.Annotated[RiskStatus, FieldMetadata(alias="riskStatus")]
    risk_reason: typing_extensions.Annotated[RiskReason, FieldMetadata(alias="riskReason")]
    risk_action: typing_extensions.Annotated[RiskAction, FieldMetadata(alias="riskAction")]
    risk_action_code: typing_extensions.Annotated[RiskActionCode, FieldMetadata(alias="riskActionCode")]
    device_id: typing_extensions.Annotated[Device, FieldMetadata(alias="deviceId")]
    ach_sec_code: typing_extensions.Annotated[AchSecCode, FieldMetadata(alias="achSecCode")]
    ach_holder_type: typing_extensions.Annotated[AchHolderType, FieldMetadata(alias="achHolderType")]
    ip_address: typing_extensions.Annotated[IpAddress, FieldMetadata(alias="ipAddress")]
    is_same_day_ach: typing_extensions.Annotated[bool, FieldMetadata(alias="isSameDayACH")]
    wallet_type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="walletType")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.order_id import OrderId
from ...types.orderdescription import Orderdescription
from ...types.source import Source


class TransactionDetailPaymentDetails(UniversalBaseModel):
    """
    Detailed breakdown of payment amounts and identifiers
    """

    total_amount: typing_extensions.Annotated[float, FieldMetadata(alias="totalAmount")]
    service_fee: typing_extensions.Annotated[float, FieldMetadata(alias="serviceFee")]
    check_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="checkNumber")] = None
    check_image: typing_extensions.Annotated[typing.Optional[typing.Any], FieldMetadata(alias="checkImage")] = None
    check_unique_id: typing_extensions.Annotated[str, FieldMetadata(alias="checkUniqueId")]
    currency: str
    order_description: typing_extensions.Annotated[
        typing.Optional[Orderdescription], FieldMetadata(alias="orderDescription")
    ] = None
    order_id: typing_extensions.Annotated[typing.Optional[OrderId], FieldMetadata(alias="orderId")] = None
    order_id_alternative: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="orderIdAlternative")
    ] = None
    payment_description: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="paymentDescription")
    ] = None
    group_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="groupNumber")] = None
    source: typing.Optional[Source] = None
    payabli_trans_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="payabliTransId")] = None
    unbundled: typing.Optional[typing.Any] = None
    categories: typing.List[typing.Any]
    split_funding: typing_extensions.Annotated[typing.List[typing.Any], FieldMetadata(alias="splitFunding")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.authcode import Authcode
from ...types.avsresponsetext import Avsresponsetext
from ...types.customeridtrans import Customeridtrans
from ...types.cvvresponsetext import Cvvresponsetext
from ...types.method_reference_id import MethodReferenceId
from ...types.referenceidtrans import Referenceidtrans
from ...types.result_code import ResultCode
from ...types.resulttext import Resulttext
from .transaction_detail_record import TransactionDetailRecord


class GetPaidResponseData(UniversalBaseModel):
    """
    Response data for GetPaid transactions
    """

    transaction_details: typing_extensions.Annotated[
        typing.Optional[TransactionDetailRecord], FieldMetadata(alias="transactionDetails")
    ] = pydantic.Field(default=None)
    """
    Details of the transaction. Present only if `includeDetails` query parameter is set to `true` in the request.
    """

    auth_code: typing_extensions.Annotated[typing.Optional[Authcode], FieldMetadata(alias="authCode")] = None
    reference_id: typing_extensions.Annotated[Referenceidtrans, FieldMetadata(alias="referenceId")]
    result_code: typing_extensions.Annotated[ResultCode, FieldMetadata(alias="resultCode")]
    result_text: typing_extensions.Annotated[Resulttext, FieldMetadata(alias="resultText")]
    avs_response_text: typing_extensions.Annotated[Avsresponsetext, FieldMetadata(alias="avsResponseText")]
    cvv_response_text: typing_extensions.Annotated[Cvvresponsetext, FieldMetadata(alias="cvvResponseText")]
    customer_id: typing_extensions.Annotated[Customeridtrans, FieldMetadata(alias="customerId")]
    method_reference_id: typing_extensions.Annotated[
        typing.Optional[MethodReferenceId], FieldMetadata(alias="methodReferenceId")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
